@@ -164,6 +164,13 @@ public final class RakOps {
         return res;
     }
 
+    public static SixModelObject p6box_u(long value, ThreadContext tc) {
+        GlobalExt gcx = key.getGC(tc);
+        SixModelObject res = gcx.Int.st.REPR.allocate(tc, gcx.Int.st);
+        res.set_int(tc, value);
+        return res;
+    }
+
     public static SixModelObject p6box_n(double value, ThreadContext tc) {
         GlobalExt gcx = key.getGC(tc);
         SixModelObject res = gcx.Num.st.REPR.allocate(tc, gcx.Num.st);
@@ -187,6 +194,9 @@ public final class RakOps {
                 case CallSiteDescriptor.ARG_INT:
                     toBind = p6box_i((long)args[i], tc);
                     break;
+                case CallSiteDescriptor.ARG_UINT:
+                    toBind = p6box_u((long)args[i], tc);
+                    break;
                 case CallSiteDescriptor.ARG_NUM:
                     toBind = p6box_n((double)args[i], tc);
                     break;
@@ -408,7 +418,6 @@ public final class RakOps {
     }
 
     public static SixModelObject p6captureouters2(SixModelObject capList, SixModelObject target, ThreadContext tc) {
-        GlobalExt gcx = key.getGC(tc);
         if (!(target instanceof CodeRef))
             ExceptionHandling.dieInternal(tc, "p6captureouters target must be a CodeRef");
         CallFrame cf = ((CodeRef)target).outer;
@@ -416,10 +425,8 @@ public final class RakOps {
             return capList;
         long elems = capList.elems(tc);
         for (long i = 0; i < elems; i++) {
-            SixModelObject codeObj = capList.at_pos_boxed(tc, i);
-            CodeRef closure = (CodeRef)codeObj.get_attribute_boxed(tc,
-                gcx.Code, "$!do", HINT_CODE_DO);
-            CallFrame ctxToDiddle = closure.outer;
+            SixModelObject closure = capList.at_pos_boxed(tc, i);
+            CallFrame ctxToDiddle = ((CodeRef)closure).outer;
             ctxToDiddle.outer = cf;
         }
         return capList;
@@ -479,34 +486,13 @@ public final class RakOps {
             + in.substring(Character.charCount(first)).toLowerCase();
     }
 
-    private static final CallSiteDescriptor SortCSD = new CallSiteDescriptor(
-        new byte[] { CallSiteDescriptor.ARG_OBJ, CallSiteDescriptor.ARG_OBJ }, null);
-    public static SixModelObject p6sort(SixModelObject indices, final SixModelObject comparator, final ThreadContext tc) {
-        int elems = (int)indices.elems(tc);
-        SixModelObject[] sortable = new SixModelObject[elems];
-        for (int i = 0; i < elems; i++)
-            sortable[i] = indices.at_pos_boxed(tc, i);
-        Arrays.sort(sortable, new Comparator<SixModelObject>() {
-            public int compare(SixModelObject a, SixModelObject b) {
-                Ops.invokeDirect(tc, comparator, SortCSD,
-                    new Object[] { a, b });
-                return (int)Ops.result_i(tc.curFrame);
-            }
-        });
-        for (int i = 0; i < elems; i++)
-            indices.bind_pos_boxed(tc, i, sortable[i]);
-        return indices;
-    }
-
     public static long p6stateinit(ThreadContext tc) {
         return tc.curFrame.stateInit ? 1 : 0;
     }
 
     public static SixModelObject p6setfirstflag(SixModelObject codeObj, ThreadContext tc) {
-        GlobalExt gcx = key.getGC(tc);
         ThreadExt tcx = key.getTC(tc);
-        tcx.firstPhaserCodeBlock = codeObj.get_attribute_boxed(tc,
-            gcx.Code, "$!do", HINT_CODE_DO);
+        tcx.firstPhaserCodeBlock = codeObj;
         return codeObj;
     }
 
